@@ -8,22 +8,26 @@
 
 from yams.buildobjs import EntityType, Datetime, String, RelationDefinition
 
+
 class Fpasswd(EntityType):
     # Fpasswd handled by internal hooks, simply let managers removing manually
     # if desired
-    __permissions__ = {'read':   ('managers',),
-                       'add':    (),
-                       'delete': ('managers',),
-                       'update': (),
-                       }
+    __permissions__ = {
+        "read": ("managers",),
+        "add": (),
+        "delete": ("managers",),
+        "update": (),
+    }
     revocation_id = String(required=True, unique=True)
     revocation_date = Datetime(required=True)
 
+
 class has_fpasswd(RelationDefinition):
-    __permissions__ = {'read': ('managers',),
-                       'add':    (),
-                       'delete': ('managers',),
-                       }
-    subject = 'CWUser'
-    object = 'Fpasswd'
-    cardinality = '*1'
+    __permissions__ = {
+        "read": ("managers",),
+        "add": (),
+        "delete": ("managers",),
+    }
+    subject = "CWUser"
+    object = "Fpasswd"
+    cardinality = "*1"
