@@ -9,7 +9,10 @@
 from logilab.common.testlib import unittest_main
 from cubicweb.devtools.testlib import AutomaticWebTest
 
-class AutomaticWebTest(AutomaticWebTest): pass
 
-if __name__ == '__main__':
+class AutomaticWebTest(AutomaticWebTest):
+    pass
+
+
+if __name__ == "__main__":
     unittest_main()
